==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/DeviceAssuranceAndroidPlatformAllOfScreenLockType.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ScreenLockType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DeviceAssuranceAndroidPlatformAllOfScreenLockType
 */
@JsonPropertyOrder({ DeviceAssuranceAndroidPlatformAllOfScreenLockType.JSON_PROPERTY_INCLUDE })
@JsonTypeName("DeviceAssuranceAndroidPlatform_allOf_screenLockType")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class DeviceAssuranceAndroidPlatformAllOfScreenLockType implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<ScreenLockType> include = null;

    public DeviceAssuranceAndroidPlatformAllOfScreenLockType() {
    }

    public DeviceAssuranceAndroidPlatformAllOfScreenLockType include(List<ScreenLockType> include) {

        this.include = include;
        return this;
    }

    public DeviceAssuranceAndroidPlatformAllOfScreenLockType addincludeItem(ScreenLockType includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * Get include
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<ScreenLockType> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<ScreenLockType> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceAndroidPlatformAllOfScreenLockType deviceAssuranceAndroidPlatformAllOfScreenLockType = (DeviceAssuranceAndroidPlatformAllOfScreenLockType) o;
        return Objects.equals(this.include, deviceAssuranceAndroidPlatformAllOfScreenLockType.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceAndroidPlatformAllOfScreenLockType {\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: com/okta/sdk/resource/model/DeviceAssuranceAndroidPlatformAllOfScreenLockType.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.ScreenLockType;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DeviceAssuranceAndroidPlatformAllOfScreenLockType
 */
@JsonPropertyOrder({ DeviceAssuranceAndroidPlatformAllOfScreenLockType.JSON_PROPERTY_INCLUDE })
@JsonTypeName("DeviceAssuranceAndroidPlatform_allOf_screenLockType")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class DeviceAssuranceAndroidPlatformAllOfScreenLockType implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_INCLUDE = "include";
    private List<ScreenLockType> include = null;

    public DeviceAssuranceAndroidPlatformAllOfScreenLockType() {
    }

    public DeviceAssuranceAndroidPlatformAllOfScreenLockType include(List<ScreenLockType> include) {

        this.include = include;
        return this;
    }

    public DeviceAssuranceAndroidPlatformAllOfScreenLockType addincludeItem(ScreenLockType includeItem) {
        if (this.include == null) {
            this.include = new ArrayList<>();
        }
        this.include.add(includeItem);
        return this;
    }

    /**
     * Get include
     *
     * @return include
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<ScreenLockType> getInclude() {
        return include;
    }

    @JsonProperty(JSON_PROPERTY_INCLUDE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setInclude(List<ScreenLockType> include) {
        this.include = include;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DeviceAssuranceAndroidPlatformAllOfScreenLockType deviceAssuranceAndroidPlatformAllOfScreenLockType = (DeviceAssuranceAndroidPlatformAllOfScreenLockType) o;
        return Objects.equals(this.include, deviceAssuranceAndroidPlatformAllOfScreenLockType.include);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(include);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DeviceAssuranceAndroidPlatformAllOfScreenLockType {\n");
        sb.append("    include: ").append(toIndentedString(include)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
